@@ -8,8 +8,8 @@ import dbus
 #Classes
 ###########################################################################################
 class Notifications:
-	def __init__(self,parent = None):
-		self.bus = dbus.SessionBus()
+	def __init__(self, parent):
+		self.bus = parent.bus
 		self.object = self.bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		self.interface = dbus.Interface(self.object,dbus_interface='org.freedesktop.Notifications')
 
